@@ -39,7 +39,7 @@ def get_message(from_address, to_address, content, subject, attachs=None, is_htm
         with open(attach, "rb") as attach_file:
             basename = os.path.basename(attach)
             part = MIMEApplication(attach_file.read(), Name=basename)
-        part.add_header('Content-Disposition', 'attachment', filename=basename)
+        part.add_header("Content-Disposition", "attachment", filename=("utf-8", "", basename))
         message.attach(part)
 
     return message
@@ -48,10 +48,7 @@ def get_message(from_address, to_address, content, subject, attachs=None, is_htm
 def sendmail(from_address, to_address, content, subject, attachs=None, is_html_content=False, content_encoding="utf-8", host="127.0.0.1", port=25, ssl=False, user=None, password=None):
     smtp_service = get_smtp_service(host, port, ssl, user, password)
     message = get_message(from_address, to_address, content, subject, attachs, is_html_content, content_encoding)
-    if hasattr(smtp_service, "send_message"):
-        smtp_service.send_message(message) # Python 2.7 or 3.x 
-    else:
-        smtp_service.sendmail(from_address, to_address, message.to_string()) # Python 2.6
+    smtp_service.send_message(message) # Python2.6 无法支撑 :-(
     smtp_service.quit()
 
 
@@ -69,7 +66,7 @@ def sendmail(from_address, to_address, content, subject, attachs=None, is_html_c
 @click.option("-P", "--password", help=u"邮箱代理服务器密码，不提供则表示无需帐号认证。")
 @click.argument("content", nargs=1, required=False)
 def main(from_address, to_address, subject, content, attach, html, encoding, host, port, ssl, user, password):
-    """通过代理服务器发送邮件。
+    u"""通过代理服务器发送邮件。
     
     注意： 
     
@@ -78,8 +75,8 @@ def main(from_address, to_address, subject, content, attach, html, encoding, hos
     if not content:
         content = os.sys.stdin.read()
     sendmail(from_address, to_address, content, subject, attach, html, encoding, host, port, ssl, user, password)
-    click.echo("邮件发送成功。主题：[{subject}]，发件人：[{from_address}]，收件人：[{to_address}]。".format(
-        subject=subject or "(no subject)",
+    click.echo(u"邮件发送成功。主题：[{subject}]，发件人：[{from_address}]，收件人：[{to_address}]。".format(
+        subject=subject or u"(no subject)",
         from_address=from_address,
         to_address=to_address
         ))
